@@ -489,6 +489,9 @@ class Series(SeriesMagicMethodMixin):
             error_values = {}
             data = self._data[:]
             for i, array in enumerate(self):
+                if not isinstance(array, list):
+                    array = deserialize_list(array)
+
                 try:
                     series = Series(
                         **self.get_schema(
